@@ -23,12 +23,11 @@ use base qw( Vulcan::SQLiteDB );
 
 =head1 DATABASE
 
-A SQLITE db has a <ceres> table of I<four> columns:
+A SQLITE db has a <ceres> table of I<three> columns:
 
  host : hostname
- time : collection time/flag
  key : md5 key
- md5 : current md5
+ sig : current md5 signature
 
 =cut
 our $TABLE  = 'ceres';
@@ -37,7 +36,7 @@ sub define
 {
     host => 'TEXT NOT NULL PRIMARY KEY',
     key => 'TEXT NOT NULL',
-    md5 => 'TEXT NOT NULL',
+    sig => 'TEXT NOT NULL',
 };
 
 sub new
@@ -49,35 +48,35 @@ sub new
 
 =head1 METHODS
 
-=head3 update( $host, $key, $md5 )
+=head3 update( $host, $key, $sig )
 
-Update record if I<key> or I<md5> changed.
+Update record if I<key> or I<sig> changed.
 
 =cut
 sub update
 {
-    my ( $self, $host, $key, $md5 ) = splice @_;
+    my ( $self, $host, $key, $sig ) = splice @_;
 
     $self->delete( $TABLE, host => [ 0, $host ], key => [ 1, $key ] );
     $self->delete( $TABLE, host => [ 1, $host ], key => [ 0, $key ] );
 
     my ( $record ) = $self->select( $TABLE => '*', host => [ 1, $host ] );
-    $self->insert( $TABLE, $host, $key, $md5 )
-        unless $record && $record->[2] eq $md5;
+    $self->insert( $TABLE, $host, $key, $sig )
+        unless $record && $record->[2] eq $sig;
 }
 
-=head3 index( $host, $md5 )
+=head3 index( $host, $sig )
 
-Select I<key> by $host, and by failed I<md5> match if $md5 is defined.
+Select I<key> by $host, and by failed I<sig> match if $sig is defined.
 Return last two characters of I<key>, or undef if $host does not exist.
 
 =cut
 sub index
 {
-    my ( $self, $host, $md5 ) = splice @_;
+    my ( $self, $host, $sig ) = splice @_;
     my %query = ( host => [ 1, $host ] );
 
-    $query{md5} = [ 0, $md5 ] if defined $md5;
+    $query{sig} = [ 0, $sig ] if defined $sig;
     my ( $record ) = $self->select( $TABLE => '*', %query );
     return $record ? substr $record->[1], -2, 2 : undef;
 }
