@@ -8,12 +8,14 @@ Pan::Repo - group management interface
 
  use Pan::Repo;
 
- my $pan = Pan::Repo->new
+ my $repo = Pan::Repo->new
  (
      conf => '/conf/file',
      path => '/path/file',
  );
 
+ my %conf = $repo->dump
+
 =cut
 use strict;
 use warnings;
