@@ -29,8 +29,11 @@ sub sudo
     my ( $class, $user ) = splice @_;
     my $me = ( getpwuid $< )[0];
 
-    return $user if $me eq ( $user ||= 'root' ) 
-        || POSIX::setuid( ( getpwnam $user )[2] );
+    return $user if $me eq ( $user ||= 'root' );
+    confess "invalid user $user\n" unless my @pw = getpwnam $user;
+    @pw = map { 0 + sprintf '%d', $_ } @pw[2,3];
+    POSIX::setgid( $pw[1] );
+    return $user if POSIX::setuid( $pw[0] );
 
     warn "$me: need '$user' privilege, invoking sudo.\n";
     confess "exec $0: $!" unless exec 'sudo', '-u', $user, $0, @ARGV;
